summaryrefslogtreecommitdiffstats
path: root/src/tools/controller
diff options
context:
space:
mode:
Diffstat (limited to 'src/tools/controller')
-rw-r--r--src/tools/controller/controller.cpp9
-rw-r--r--src/tools/controller/interrupthandler.cpp3
-rw-r--r--src/tools/controller/interrupthandler.h3
3 files changed, 9 insertions, 6 deletions
diff --git a/src/tools/controller/interrupthandler.cpp b/src/tools/controller/interrupthandler.cpp
index f14fe43a..032ea23a 100644
--- a/src/tools/controller/interrupthandler.cpp
+++ b/src/tools/controller/interrupthandler.cpp
@@ -1,9 +1,10 @@
/****************************************************************************
**
+** Copyright (C) 2019 Luxoft Sweden AB
** Copyright (C) 2018 Pelagicore AG
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the Pelagicore Application Manager.
+** This file is part of the Luxoft Application Manager.
**
** $QT_BEGIN_LICENSE:GPL-EXCEPT-QTAS$
** Commercial License Usage
diff --git a/src/tools/controller/interrupthandler.h b/src/tools/controller/interrupthandler.h
index 1c3eae61..7674afe2 100644
--- a/src/tools/controller/interrupthandler.h
+++ b/src/tools/controller/interrupthandler.h
@@ -1,9 +1,10 @@
/****************************************************************************
**
+** Copyright (C) 2019 Luxoft Sweden AB
** Copyright (C) 2018 Pelagicore AG
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the Pelagicore Application Manager.
+** This file is part of the Luxoft Application Manager.
**
** $QT_BEGIN_LICENSE:GPL-EXCEPT-QTAS$
** Commercial License Usage
diff --git a/src/tools/controller/controller.cpp b/src/tools/controller/controller.cpp
index 1bd9eb52..e63e36d8 100644
--- a/src/tools/controller/controller.cpp
+++ b/src/tools/controller/controller.cpp
@@ -1,9 +1,10 @@
/****************************************************************************
**
+** Copyright (C) 2019 Luxoft Sweden AB
** Copyright (C) 2018 Pelagicore AG
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Pelagicore Application Manager.
**
** $QT_BEGIN_LICENSE:GPL-EXCEPT-QTAS$
** Commercial License Usage
@@ -231,13 +232,13 @@ private:
int main(int argc, char *argv[])
{
QCoreApplication::setApplicationName(qSL("ApplicationManager Controller"));
- QCoreApplication::setOrganizationName(qSL("Pelagicore AG"));
- QCoreApplication::setOrganizationDomain(qSL("pelagicore.com"));
+ QCoreApplication::setOrganizationName(qSL("Luxoft Sweden AB"));
+ QCoreApplication::setOrganizationDomain(qSL("luxoft.com"));
QCoreApplication::setApplicationVersion(qSL(AM_VERSION));
ThrowingApplication a(argc, argv);
- QString desc = qSL("\nPelagicore ApplicationManager controller tool\n\nAvailable commands are:\n");
+ QString desc = qSL("\nLuxoft ApplicationManager controller tool\n\nAvailable commands are:\n");
uint longestName = 0;
for (uint i = 0; i < sizeof(commandTable) / sizeof(commandTable[0]); ++i)
longestName = qMax(longestName, qstrlen(commandTable[i].name));
@@ -1,9 +1,10 @@
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the Pelagicore Application Manager.
+** This file is part of the Luxoft Application Manager.
**
** $QT_BEGIN_LICENSE:GPL-EXCEPT-QTAS$